@@ -130,9 +130,10 @@ class DynamixelXL430():
                 self.port_handler = port_handler
             self.packet_handler = pch.PacketHandler(2.0)
         except serial.SerialException as e:
-            self.logger.error("SerialException({0}): {1}".format(e.errno, e.strerror))
+            self.logger.error("Dynamixel SerialException({1}): {2}".format(self.usb,e.errno, e.strerror))
         self.hw_valid = self.packet_handler is not None
 
+
     @staticmethod
     def identify_baud_rate(dxl_id, usb):
         """Identify the baud rate a Dynamixel servo is communicating at.
@@ -149,15 +150,18 @@ class DynamixelXL430():
         int
             the baud rate the Dynamixel is communicating at
         """
-        for b in BAUD_MAP.keys():
-            port_h = prh.PortHandler(usb)
-            port_h.openPort()
-            port_h.setBaudRate(b)
-            packet_h = pch.PacketHandler(2.0)
-            _, dxl_comm_result, _ = packet_h.ping(port_h, dxl_id)
-            port_h.closePort()
-            if dxl_comm_result == COMM_SUCCESS:
-                return b
+        try:
+            for b in BAUD_MAP.keys():
+                port_h = prh.PortHandler(usb)
+                port_h.openPort()
+                port_h.setBaudRate(b)
+                packet_h = pch.PacketHandler(2.0)
+                _, dxl_comm_result, _ = packet_h.ping(port_h, dxl_id)
+                port_h.closePort()
+                if dxl_comm_result == COMM_SUCCESS:
+                    return b
+        except:
+            pass
         return -1
 
     def startup(self):
@@ -169,12 +173,13 @@ class DynamixelXL430():
                 if baud!=self.baud:
                     self.logger.error('DynamixelCommError. Mismatched baud rate. Expected %d but servo is set to %d.'%(self.baud,baud))
                 else:
-                    self.logger.error('DynamixelCommError. Unable to enable torque')
+                    self.logger.error('DynamixelCommError. Failed to startup servo %s at id %d . Check that id and usb bus are valid'%(self.usb,self.dxl_id))
                 self.hw_valid=False
                 return False
             return True
         return False
 
+
     def stop(self):
         if self.hw_valid:
             self.hw_valid = False
@@ -256,9 +261,9 @@ class DynamixelXL430():
             with self.pt_lock:
                 dxl_model_number, dxl_comm_result, dxl_error = self.packet_handler.ping(self.port_handler, self.dxl_id)
             if self.handle_comm_result('XL430_PING', dxl_comm_result, dxl_error):
-                self.logger.debug("[Dynamixel ID:%03d] ping Succeeded. Dynamixel model number : %d" % (self.dxl_id, dxl_model_number))
+                self.logger.debug("[Dynamixel ID:%03d] ping Succeeded. Dynamixel model number : %d. Baud %d" % (self.dxl_id, dxl_model_number, self.baud))
                 if verbose:
-                    print("[Dynamixel ID:%03d] ping Succeeded. Dynamixel model number : %d" % (self.dxl_id, dxl_model_number))
+                    print("[Dynamixel ID:%03d] ping Succeeded. Dynamixel model number : %d. Baud %d" % (self.dxl_id, dxl_model_number, self.baud))
                 return True
             else:
                 self.logger.debug("[Dynamixel ID:%03d] ping Failed." % (self.dxl_id))
@@ -281,7 +286,7 @@ class DynamixelXL430():
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write1ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_ID, id)
+            dxl_comm_result, dxl_error =   self.packet_handler.write1ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_ID, int(id))
         self.handle_comm_result('XL430_ADDR_ID', dxl_comm_result, dxl_error)
 
     def get_baud_rate(self):
@@ -338,7 +343,7 @@ class DynamixelXL430():
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write1ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_HELLO_CALIBRATED, x)
+            dxl_comm_result, dxl_error =   self.packet_handler.write1ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_HELLO_CALIBRATED, int(x!=0))
         self.handle_comm_result('XL430_ADDR_HELLO_CALIBRATED', dxl_comm_result, dxl_error)
 
     def do_reboot(self):
@@ -397,21 +402,39 @@ class DynamixelXL430():
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error = self.packet_handler.write1ByteTxRx(self.port_handler, self.dxl_id,XL430_ADDR_RETURN_DELAY_TIME, x)
+            dxl_comm_result, dxl_error = self.packet_handler.write1ByteTxRx(self.port_handler, self.dxl_id,XL430_ADDR_RETURN_DELAY_TIME, int(x))
         self.handle_comm_result('XL430_ADDR_RETURN_DELAY_TIME', dxl_comm_result, dxl_error)
 
+    def get_return_delay_time(self):
+        if not self.hw_valid:
+            return 0
+        with self.pt_lock:
+            p, dxl_comm_result, dxl_error = self.packet_handler.read1ByteTxRx(self.port_handler, self.dxl_id,
+                                                                              XL430_ADDR_RETURN_DELAY_TIME)
+        self.handle_comm_result('XL430_ADDR_HARDWARE_ERROR_STATUS', dxl_comm_result, dxl_error)
+        return p
+
     def set_pwm(self,x):
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_GOAL_PWM, x)
+            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_GOAL_PWM, int(x))
         self.handle_comm_result('XL430_ADDR_GOAL_PWM', dxl_comm_result, dxl_error)
 
     def set_current_limit(self,i):
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XM430_ADDR_CURRENT_LIMIT, i)
+            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XM430_ADDR_CURRENT_LIMIT, int(i))
         self.handle_comm_result('XM430_ADDR_CURRENT_LIMIT', dxl_comm_result, dxl_error)
 
+    def get_current_limit(self):
+        if not self.hw_valid:
+            return 0
+        with self.pt_lock:
+            p, dxl_comm_result, dxl_error = self.packet_handler.read2ByteTxRx(self.port_handler, self.dxl_id,
+                                                                              XM430_ADDR_CURRENT_LIMIT)
+        self.handle_comm_result('XM430_ADDR_CURRENT_LIMIT', dxl_comm_result, dxl_error)
+        return p
+
     def enable_multiturn(self):
         if not self.hw_valid:
             return
@@ -484,23 +507,73 @@ class DynamixelXL430():
     #XM Series
     def set_goal_current(self,i):
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XM430_ADDR_GOAL_CURRENT, i)
+            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XM430_ADDR_GOAL_CURRENT, int(i))
         self.handle_comm_result('XM430_ADDR_GOAL_CURRENT', dxl_comm_result, dxl_error)
 
+    def get_goal_current(self):
+        if not self.hw_valid:
+            return 0
+        with self.pt_lock:
+            p, dxl_comm_result, dxl_error = self.packet_handler.read2ByteTxRx(self.port_handler, self.dxl_id,
+                                                                              XM430_ADDR_GOAL_CURRENT)
+        self.handle_comm_result('XM430_ADDR_GOAL_CURRENT', dxl_comm_result, dxl_error)
+        return p
 
     def go_to_pos(self,x):
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write4ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_GOAL_POSITION, x)
+            dxl_comm_result, dxl_error =   self.packet_handler.write4ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_GOAL_POSITION, int(x))
         self.handle_comm_result('XL430_ADDR_GOAL_POSITION', dxl_comm_result, dxl_error)
 
     def set_vel(self, x):
         with self.pt_lock:
             dxl_comm_result, dxl_error = self.packet_handler.write4ByteTxRx(self.port_handler, self.dxl_id,
-                                                                            XL430_ADDR_GOAL_VEL, x)
+                                                                            XL430_ADDR_GOAL_VEL, int(x))
         self.handle_comm_result('XL430_ADDR_GOAL_VEL', dxl_comm_result, dxl_error)
 
+    def enable_watchdog(self, timeout_20msec=50):
+        """Enables bus monitoring to stop safely if communications fails.
+
+        In any operating mode, a watchdog may be enabled on the Dynamixel
+        hardware. If bus communication ceases for longer than a specified
+        timeout, the hardware enters watchdog error mode. New commands will
+        not execute until watchdog is disabled. Watchdog can be used with
+        velocity control to prevent undesired behavior in case of software
+        failure.
+
+        Parameters
+        ----------
+        timeout_20msec : int
+            value in range [1, 127] calculates timeout as value * 20 milliseconds (default 1s)
+        """
+        with self.pt_lock:
+            dxl_comm_result, dxl_error =   self.packet_handler.write1ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_BUS_WATCHDOG, timeout_20msec)
+        self.handle_comm_result('XL430_ADDR_BUS_WATCHDOG', dxl_comm_result, dxl_error)
+
+    def disable_watchdog(self):
+        """Disables watchdog bus monitoring.
+
+        In case of watchdog error occurred, no new goal commands will execute
+        until watchdog disabled with this function.
+        """
+        with self.pt_lock:
+            dxl_comm_result, dxl_error =   self.packet_handler.write1ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_BUS_WATCHDOG, 0)
+        self.handle_comm_result('XL430_ADDR_BUS_WATCHDOG', dxl_comm_result, dxl_error)
+
+    def get_watchdog_error(self):
+        """Checks if watchdog error occurred.
+
+        Returns
+        -------
+        bool
+            True if watchdog detected no communication for longer than watchdog timeout
+        """
+        with self.pt_lock:
+            p, dxl_comm_result, dxl_error =   self.packet_handler.read1ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_BUS_WATCHDOG)
+        self.handle_comm_result('XL430_ADDR_BUS_WATCHDOG', dxl_comm_result, dxl_error)
+        return p == 255
+
     def get_pos(self):
         if not self.hw_valid:
             return 0
@@ -533,19 +606,18 @@ class DynamixelXL430():
         self.handle_comm_result('XL430_ADDR_PRESENT_PWM', dxl_comm_result, dxl_error)
         return xn
 
-
     def set_profile_velocity(self,v):
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write4ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_PROFILE_VELOCITY, v)
+            dxl_comm_result, dxl_error =   self.packet_handler.write4ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_PROFILE_VELOCITY, int(v))
         self.handle_comm_result('XL430_ADDR_PROFILE_VELOCITY', dxl_comm_result, dxl_error)
 
     def set_profile_acceleration(self, a):
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error = self.packet_handler.write4ByteTxRx(self.port_handler, self.dxl_id,XL430_ADDR_PROFILE_ACCELERATION, a)
+            dxl_comm_result, dxl_error = self.packet_handler.write4ByteTxRx(self.port_handler, self.dxl_id,XL430_ADDR_PROFILE_ACCELERATION, int(a))
         self.handle_comm_result('XL430_ADDR_PROFILE_ACCELERATION', dxl_comm_result, dxl_error)
 
 
@@ -587,7 +659,7 @@ class DynamixelXL430():
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_POS_P_GAIN, x)
+            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_POS_P_GAIN, int(x))
         self.handle_comm_result('XL430_ADDR_POS_P_GAIN', dxl_comm_result, dxl_error)
 
     def get_D_gain(self):
@@ -602,7 +674,7 @@ class DynamixelXL430():
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_POS_D_GAIN, x)
+            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_POS_D_GAIN, int(x))
         self.handle_comm_result('XL430_ADDR_POS_D_GAIN', dxl_comm_result, dxl_error)
 
     def get_I_gain(self):
@@ -617,7 +689,7 @@ class DynamixelXL430():
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_POS_I_GAIN, x)
+            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_POS_I_GAIN, int(x))
         self.handle_comm_result('XL430_ADDR_POS_I_GAIN', dxl_comm_result, dxl_error)
 
     def get_temperature_limit(self):
@@ -632,10 +704,9 @@ class DynamixelXL430():
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write1ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_TEMPERATURE_LIMIT, x)
+            dxl_comm_result, dxl_error =   self.packet_handler.write1ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_TEMPERATURE_LIMIT, int(x))
         self.handle_comm_result('XL430_ADDR_TEMPERATURE_LIMIT', dxl_comm_result, dxl_error)
 
-
     def get_max_voltage_limit(self):
         if not self.hw_valid:
             return 0
@@ -648,7 +719,7 @@ class DynamixelXL430():
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_MAX_VOLTAGE_LIMIT, x)
+            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_MAX_VOLTAGE_LIMIT, int(x))
         self.handle_comm_result('XL430_ADDR_MAX_VOLTAGE_LIMIT', dxl_comm_result, dxl_error)
 
     def get_min_voltage_limit(self):
@@ -663,7 +734,7 @@ class DynamixelXL430():
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_MIN_VOLTAGE_LIMIT, x)
+            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_MIN_VOLTAGE_LIMIT, int(x))
         self.handle_comm_result('XL430_ADDR_MIN_VOLTAGE_LIMIT', dxl_comm_result, dxl_error)
 
     def get_vel_limit(self):
@@ -678,7 +749,7 @@ class DynamixelXL430():
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write4ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_VELOCITY_LIMIT, x)
+            dxl_comm_result, dxl_error =   self.packet_handler.write4ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_VELOCITY_LIMIT, int(x))
         self.handle_comm_result('XL430_ADDR_VELOCITY_LIMIT', dxl_comm_result, dxl_error)
 
     def get_max_pos_limit(self):
@@ -693,17 +764,16 @@ class DynamixelXL430():
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write4ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_MAX_POS_LIMIT, x)
+            dxl_comm_result, dxl_error =   self.packet_handler.write4ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_MAX_POS_LIMIT, int(x))
         self.handle_comm_result('XL430_ADDR_MAX_POS_LIMIT', dxl_comm_result, dxl_error)
 
     def set_min_pos_limit(self,x):
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write4ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_MIN_POS_LIMIT, x)
+            dxl_comm_result, dxl_error =   self.packet_handler.write4ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_MIN_POS_LIMIT, int(x))
         self.handle_comm_result('XL430_ADDR_MIN_POS_LIMIT', dxl_comm_result, dxl_error)
 
-
     def get_min_pos_limit(self):
         if not self.hw_valid:
             return 0
@@ -724,14 +794,23 @@ class DynamixelXL430():
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write4ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_MOVING_THRESHOLD, x)
+            dxl_comm_result, dxl_error =   self.packet_handler.write4ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_MOVING_THRESHOLD, int(x))
         self.handle_comm_result('XL430_ADDR_MOVING_THRESHOLD', dxl_comm_result, dxl_error)
 
+    def get_moving_threshold(self):
+        if not self.hw_valid:
+            return 0
+        with self.pt_lock:
+            p, dxl_comm_result, dxl_error = self.packet_handler.read4ByteTxRx(self.port_handler, self.dxl_id,
+                                                                              XL430_ADDR_MOVING_THRESHOLD)
+        self.handle_comm_result('XL430_ADDR_MOVING_THRESHOLD', dxl_comm_result, dxl_error)
+        return p
+
     def set_pwm_limit(self,x): #0(0%) ~ 885(100%
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_PWM_LIMIT, x)
+            dxl_comm_result, dxl_error =   self.packet_handler.write2ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_PWM_LIMIT, int(x))
         self.handle_comm_result('XL430_ADDR_PWM_LIMIT', dxl_comm_result, dxl_error)
 
     def get_pwm_limit(self):
@@ -781,5 +860,5 @@ class DynamixelXL430():
         if not self.hw_valid:
             return
         with self.pt_lock:
-            dxl_comm_result, dxl_error = self.packet_handler.write4ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_HOMING_OFFSET, x)
+            dxl_comm_result, dxl_error = self.packet_handler.write4ByteTxRx(self.port_handler, self.dxl_id, XL430_ADDR_HOMING_OFFSET, int(x))
         self.handle_comm_result('XL430_ADDR_HOMING_OFFSET', dxl_comm_result, dxl_error)
