@@ -161,7 +161,7 @@ class PimuBase(Device):
     TRIGGER_LIGHTBAR_TEST = 1024
 
 
-    def __init__(self, event_reset=False):
+    def __init__(self, event_reset=False, usb=None):
         Device.__init__(self, 'pimu')
         self.config = self.params['config']
         self.lock = threading.RLock()
@@ -170,7 +170,9 @@ class PimuBase(Device):
         self._dirty_trigger = False
         self.frame_id_last = None
         self.frame_id_base = 0
-        self.transport = Transport(usb='/dev/hello-pimu', logger=self.logger)
+        if usb is None:
+            usb = self.params['usb_name']
+        self.transport = Transport(usb=usb, logger=self.logger)
         self.status = {'voltage': 0, 'current': 0, 'temp': 0,'cpu_temp': 0, 'cliff_range':[0,0,0,0], 'frame_id': 0,
                        'timestamp': 0,'at_cliff':[False,False,False,False], 'runstop_event': False, 'bump_event_cnt': 0,
                        'cliff_event': False, 'fan_on': False, 'buzzer_on': False, 'low_voltage_alert':False,'high_current_alert':False,'over_tilt_alert':False,
@@ -588,8 +590,8 @@ class Pimu(PimuBase):
     """
     API to the Stretch Power and IMU board (Pimu)
     """
-    def __init__(self, event_reset=False):
-        PimuBase.__init__(self, event_reset)
+    def __init__(self, event_reset=False, usb=None):
+        PimuBase.__init__(self, event_reset,usb)
         # Order in descending order so more recent protocols/methods override less recent
         self.supported_protocols = {'p0': (Pimu_Protocol_P0,), 'p1': (Pimu_Protocol_P1,Pimu_Protocol_P0,)}
 
