@@ -1,11 +1,36 @@
 import unittest
 import stretch_body.device
-
+import stretch_body.hello_utils
 import time
 
 
 class TestDevice(unittest.TestCase):
 
+
+    def test_write_configuration_params(self):
+        """
+        Check that we don't mangle the format when writing config params to YAML
+        """
+
+        print('\nUnittest: test_write_configuration_params')
+
+        d=stretch_body.device.Device(req_params=False)
+        cp = stretch_body.hello_utils.read_fleet_yaml('stretch_configuration_params.yaml')
+        for k in cp.keys(): #Write existing values up to 3 dict layers deep
+            key1=k
+            d.write_configuration_param_to_YAML(key1,cp[k])
+            if type(cp[k]) is dict:
+                for j in cp[k].keys():
+                    key2=key1+'.'+j
+                    d.write_configuration_param_to_YAML(key2, cp[k][j])
+                    if type(cp[k][j]) is dict:
+                        for l in cp[k][j].keys():
+                            key3 = key2 + '.' + l
+                            d.write_configuration_param_to_YAML(key3, cp[k][j][l])
+        new_cp=stretch_body.hello_utils.read_fleet_yaml('stretch_configuration_params.yaml')
+        self.assertTrue(cp==new_cp)
+
+
     def test_disable_existing_loggers(self):
         """Test multiple instances of device class all have enabled loggers.
 
@@ -14,6 +39,7 @@ class TestDevice(unittest.TestCase):
         means stretch_body classes can only initialize loggers after the config
         is loaded. We initialize config as class variables of Device for this.
         """
+        print('\nUnittest: test_disable_existing_loggers')
         d1 = stretch_body.device.Device('wrist_yaw') # loads logging config
         d2 = stretch_body.device.Device('stretch_gripper')
         d1.logger.info('hi')
@@ -22,9 +48,10 @@ class TestDevice(unittest.TestCase):
         #       verify output is '[INFO][wrist_yaw]hi\n[INFO][stretch_gripper]hi\n'
 
     def test_threaded(self):
+        print('\nUnittest: test_threaded')
         class SometimesThreadedDevice(stretch_body.device.Device):
             def __init__(self):
-                stretch_body.device.Device.__init__(self)
+                stretch_body.device.Device.__init__(self,req_params=False)
             def startup(self, threaded=False):
                 self.pulling_status = False
                 stretch_body.device.Device.startup(self, threaded=threaded)
